#
# spec file for package python-discid
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Johannes Dewender <novell@JonnyJD.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-discid
Version:        1.2.0
Release:        lp152.1.1
Summary:        Python binding of Libdiscid
License:        LGPL-3.0-or-later
Group:          Development/Libraries/Python
URL:            https://github.com/JonnyJD/python-discid
Source:         https://files.pythonhosted.org/packages/source/d/discid/discid-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libdiscid) >= 0.2.2
# no automatic requires since libdiscid is not linked
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libdiscid.so) --qf '%%{NAME} >= %%{VERSION}')
BuildArch:      noarch
%python_subpackages

%description
Python-discid implements Python bindings for MusicBrainz Libdiscid.

Libdiscid's main purpose is the calculation of an identifier of audio
discs (disc id) to use for the MusicBrainz database.

That identifier is calculated from the TOC of the disc, similar to the
freeDB CDDB identifier. Libdiscid can calculate MusicBrainz Disc IDs and
freeDB Disc IDs.
Additionally the MCN of the disc and ISRCs from the tracks can be extracted.

This module is a close binding that offloads all relevant data
storage and calculation to Libdiscid. On the other hand it gives a
pythonic API and uses objects and exceptions.

%prep
%setup -q -n discid-%{version}
sed -i "s|^#!%{_bindir}/env python$|#!python3|" examples.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# skip tests that require /dev/sr0
%python_expand py.test-%{$python_bin_suffix} -v -k "not (test_read_simple or test_read_put or test_read_features)"

%files %{python_files}
%license COPYING COPYING.LESSER
%doc CHANGES.rst README.rst
%{python_sitelib}/discid/
%{python_sitelib}/discid-%{version}-py*.egg-info

%changelog
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * various changes for pip
  * add makefile
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Thu Oct  5 2017 toddrme2178@gmail.com
- Update to version 1.1.1
  * workaround :issue:`43` for py2app problems
  * :issue:`41` improve windows example
- Run tests
- Fix shebang in examples
* Thu Oct  5 2017 avvissu@yandex.by
- Add pkgconfig(libdiscid) (build cross distribution)
- Use readlink when searching for package (build cross distribution)
- Spec file cleanup
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Jul 24 2016 rpm@fthiessen.de
- Update to current upstream release 1.1.0
* Mon Jul  4 2016 jengelh@inai.de
- Request libdiscid0 since the code looks for exactly .so.0.
- Remove redundant %%clean section.
* Thu Jun 27 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 1.0.2
  * No code changes compared to 1.0.0 release
* Tue Jun 25 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 1.0.0
  * DEFAULT_DEVICE is now get_default_device()
  * Disc.submission_url doesn’t point to a redirect now
  * fix: seconds are now rounded the same as on MB server (0.5->up)
* Fri Apr 26 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.5.0
  * feature: add Disc.mcn and Track.isrc
  * feature: add LIBDISCID_VERSION_STRING
  * feature: add Disc.seconds, Track.seconds
  and aliases Disc.length and Track.sectors
  * move read and put to module level
  * changed parameters for put() to include extra `sectors` and add TOCError
  * rename DiscId to Disc
  * fix: move track attributes to Track
  * fix: only have "real" tracks in the list(s) (0 not special)
  * fix: only read the requested features from disc (sparse)
  * fix: remove DiscId.webservice_url (deprecated)
  * fix: detect the version of libdiscid 0.3.0 also in lib64 installations
* Wed Apr 10 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.4.0
  * feature: added FEATURES_IMPLEMENTED, DiscId.track_lengths,
  DiscId.webservice_url and DiscId.freedb_id
  * feature: disc access test suite
* Mon Mar 11 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.3.0
  * feature: add FEATURES list
  * feature: DiscId.put, DiscId.track_offsets, DiscId.sectors,
  DiscId.first_track_num, DiscId.last_track_num
  * fix: prefer libdiscid in current directory
  * fix: find libdiscid in current folder (Linux/Unix)
* Wed Feb 20 2013 Johannes Dewender <novell@JonnyJD.net>
- Add version requirements
* Fri Feb  1 2013 Johannes Dewender <novell@JonnyJD.net>
- Add basic doc files to package (license, changes, example)
* Wed Jan 30 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.2.1
  * fixed Python 3.2 bug in the tests (upstream #9)
* Wed Jan 30 2013 Johannes Dewender <novell@JonnyJD.net>
- Update to python-discid 0.2.0
  * API change from DiscId.get_id to DiscId.id
  * added DEFAULT_DEVICE as a module constant
  * added DiscId.submission_url
* Mon Jan 14 2013 Johannes Dewender <novell@JonnyJD.net>
- Initial release (0.1.0)
